{% extends "admin/base.html" %}
{% load i18n admin_tools_menu_tags static %}

{% block title %}{% trans 'Admin' %}{% endblock %}
{% block extrahead %}

<!-- Javascript -->
<script type="text/javascript" src="{{ STATIC_URL }}jquery/jquery.min.js"></script>

<link media="all" href="{% static 'nvd3/src/nv.d3.css' %}" type="text/css" rel="stylesheet" />
<!--For Chart-->
<link media="all" href="{% static 'nvd3/src/nv.d3.css' %}" type="text/css" rel="stylesheet" />
<script src="{% static 'd3/d3.js' %}" type="text/javascript"></script>
<script src="{% static 'nvd3/nv.d3.js'%}" type="text/javascript"></script>

<link media="all" href="{{ STATIC_URL }}jquery-ui/themes/flick/jquery-ui.min.css" type="text/css" rel="stylesheet" />
<script type="text/javascript" src="{{ STATIC_URL }}jquery-ui/ui/minified/jquery-ui.min.js"></script>

<style>


</style>
{% endblock %}

{% block extrastyle %}
    {{ block.super }}
    {% if user.is_active and user.is_staff %}
        {% if not is_popup %}
            {% admin_tools_render_menu_css %}
        {% endif %}
    {% endif %}
{% endblock %}


{% block nav-global %}
    {% if user.is_active and user.is_staff %}
        {% if not is_popup %}
            {% admin_tools_render_menu %}
        {% endif %}
    {% endif %}
{% endblock %}
