Search.setIndex({docnames:["developer-doc","developer-doc/modules","developer-doc/objects-description","developer-doc/pre-requisite","developer-doc/testing","index","introduction"],envversion:{"sphinx.domains.c":1,"sphinx.domains.changeset":1,"sphinx.domains.cpp":1,"sphinx.domains.javascript":1,"sphinx.domains.math":1,"sphinx.domains.python":1,"sphinx.domains.rst":1,"sphinx.domains.std":1,sphinx:54},filenames:["developer-doc.rst","developer-doc/modules.rst","developer-doc/objects-description.rst","developer-doc/pre-requisite.rst","developer-doc/testing.rst","index.rst","introduction.rst"],objects:{},objnames:{},objtypes:{},terms:{"case":[0,5],"class":6,"dlouh\u00fd":6,"import":6,"static":6,"throw":6,"true":6,For:6,The:6,These:6,absolut:6,access:6,accord:6,action:6,add:6,admin:[0,4],admin_tool:6,admin_tools_stat:[4,6],advanc:3,after:6,ajax:6,all:6,allow:5,also:6,alwai:6,ani:[1,6],app:[2,6],append:6,applic:6,applist:6,arezqui:[5,6],attent:6,attribut:2,author:[5,6],avail:6,base:[5,6],base_sit:6,basic:5,beauti:6,been:6,befor:6,belaid:[5,6],bower:5,bower_components_root:6,bower_instal:6,bower_installed_app:6,bowerfind:6,bug:6,chang:6,chart:[1,5,6],check:6,children:6,code:6,collectstat:6,com:[3,6],command:6,compat:6,compon:6,configur:[2,5],consid:6,content:[0,5],context:6,contrib:6,contribut:5,copi:6,creat:[2,5,6],created_d:2,criteria:[2,5,6],criteria_dynamic_map:2,criteria_fix_map:2,criteria_nam:2,custom:6,dash_stats_criteria:2,dashboard:[1,2,5,6],dashboard_stat:2,dashboardchart:[0,6],dashboardstat:0,dashboardstatscriteria:0,data:2,date:[2,5,6],date_field_nam:2,defin:6,definit:6,demo:6,demoproject:6,depend:5,deprec:1,descript:[0,5],develop:[3,5],disabl:2,displai:6,django:[0,3,4],django_nvd3:6,djangobow:6,djangoproject:3,doc:6,don:1,download:6,dummi:[1,6],dynam:2,dynamic_criteria_field_nam:2,easili:5,enabl:2,especi:6,even:6,exampl:6,featur:6,field:2,file:6,finder:6,folder:6,follow:6,fork:6,found:6,from:5,full:4,fulli:3,get_active_graph:6,github:6,graph:[2,5,6],graph_kei:[2,6],graph_list:6,graph_titl:2,group:1,has:6,have:3,how:0,html:6,http:[3,6],improv:6,includ:6,index:[5,6],instal:5,installed_app:6,interfac:[4,6],interfer:6,introduct:5,is_vis:2,issu:6,its:6,javascript:5,join:6,json:2,jsonfield:6,just:6,kei:[2,6],keyword:[5,6],knowledg:3,kwarg:6,left:6,librari:5,licens:5,link:6,list:6,live:6,made:6,magic:6,mai:6,major:6,manag:[4,6],mani:2,might:6,migrat:6,mit:6,model:[2,5,6],model_app_nam:2,model_nam:2,modul:[0,5,6],more:1,move:6,must:6,name:2,need:[3,6],now:1,nvd3:[5,6],object:[0,5],oct:[5,6],onli:1,open:6,org:[3,6],overridden:6,page:[5,6],pai:6,pair:2,panel:6,paramet:6,patch:6,path:6,petr:6,petrdlouhi:6,pip:6,plain:6,pleas:6,plot:[5,6],post:6,prerequisit:[0,5],previou:6,project:[3,6],project_root:6,properti:6,pull:6,python:[3,4,5,6],qsstat:6,quick:6,read:6,readthedoc:6,reason:6,recent:6,recomend:6,record:2,regist:6,registr:1,relationship:2,releas:5,request:6,requir:6,require_chart_jscss:6,respect:6,rework:6,right:1,root:6,run:[0,6],search:5,section:6,see:6,select_box_:6,self:6,set:6,setup:5,some:6,sourc:6,special:5,specif:5,specifi:6,startswith:6,stat:[0,4],staticfiles_find:6,step:6,suggest:6,suit:4,support:6,tabl:2,templat:6,test:[0,5],them:6,thi:[3,6],think:6,through:6,titl:2,tool:[0,4],tracker:6,txt:6,under:6,understand:3,uninstal:6,uniqu:2,updat:[2,5],updated_d:2,upgrad:6,url:6,urlpattern:6,usag:5,use:[1,6],useful:6,user:1,using:6,valu:2,verbos:4,version:6,view:6,warn:1,welcom:6,which:6,word:2,work:6,www:3,you:[5,6],your:[5,6]},titles:["Developer Documentation","Django-admin-tools-stats Modules","Objects Description","Prerequisites","Test Case Descriptions","Django Admin Tools Stats Documentation!","Introduction"],titleterms:{"case":4,admin:[1,5,6],admintoolsstatsadmininterfacetestcas:4,basic:6,bower:6,configur:6,contribut:6,dashboardchart:1,dashboardstat:2,dashboardstatscriteria:2,depend:6,descript:[2,4],develop:[0,6],django:[1,5,6],document:[0,5,6],from:6,how:4,indic:5,instal:6,introduct:6,javascript:6,librari:6,licens:6,modul:1,object:2,prerequisit:3,run:4,setup:6,special:6,stat:[1,5,6],tabl:5,test:4,tool:[1,5,6],updat:6,usag:6}})